@@ -1,7 +1,9 @@
-/* A Bison parser, made by GNU Bison 2.1.  */
+/* A Bison parser, made by GNU Bison 2.3.  */
 
-/* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+/* Skeleton interface for Bison's Yacc-like parsers in C
+
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,10 +20,18 @@
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.  */
 
-/* As a special exception, when this file is copied by Bison into a
-   Bison output file, you may use that output file without restriction.
-   This special exception was added by the Free Software Foundation
-   in version 1.24 of Bison.  */
+/* As a special exception, you may create a larger work that contains
+   part or all of the Bison parser skeleton and distribute that work
+   under terms of your choice, so long as that work isn't itself a
+   parser generator using the skeleton or a modified version thereof
+   as a parser skeleton.  Alternatively, if you modify or redistribute
+   the parser skeleton itself, you may (at your option) remove this
+   special exception, which will cause the skeleton and the resulting
+   Bison output files to be licensed under the GNU General Public
+   License without this special exception.
+
+   This special exception was added by the Free Software Foundation in
+   version 2.2 of Bison.  */
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -48,14 +58,16 @@
      TOK_TYPESTR = 274,
      TOK_SECTION = 275,
      TOK_SECTIONDESC = 276,
-     TOK_VALUES = 277,
-     TOK_HIDDEN = 278,
-     TOK_DEPENDON = 279,
-     TOK_STRING = 280,
-     TOK_MLSTRING = 281,
-     TOK_CHAR = 282,
-     TOK_ARGTYPE = 283,
-     TOK_SIZE = 284
+     TOK_TEXT = 277,
+     TOK_ARGS = 278,
+     TOK_VALUES = 279,
+     TOK_HIDDEN = 280,
+     TOK_DEPENDON = 281,
+     TOK_STRING = 282,
+     TOK_MLSTRING = 283,
+     TOK_CHAR = 284,
+     TOK_ARGTYPE = 285,
+     TOK_SIZE = 286
    };
 #endif
 /* Tokens.  */
@@ -78,21 +90,24 @@
 #define TOK_TYPESTR 274
 #define TOK_SECTION 275
 #define TOK_SECTIONDESC 276
-#define TOK_VALUES 277
-#define TOK_HIDDEN 278
-#define TOK_DEPENDON 279
-#define TOK_STRING 280
-#define TOK_MLSTRING 281
-#define TOK_CHAR 282
-#define TOK_ARGTYPE 283
-#define TOK_SIZE 284
+#define TOK_TEXT 277
+#define TOK_ARGS 278
+#define TOK_VALUES 279
+#define TOK_HIDDEN 280
+#define TOK_DEPENDON 281
+#define TOK_STRING 282
+#define TOK_MLSTRING 283
+#define TOK_CHAR 284
+#define TOK_ARGTYPE 285
+#define TOK_SIZE 286
 
 
 
 
-#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
+#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+typedef union YYSTYPE
 #line 118 "parser.yy"
-typedef union YYSTYPE {
+{
     char   *str;
     char    chr;
     int	    argtype;
@@ -100,9 +115,10 @@ typedef union YYSTYPE {
     class AcceptedValues *ValueList;
     struct gengetopt_option *gengetopt_option;
     struct multiple_size *multiple_size;
-} YYSTYPE;
-/* Line 1447 of yacc.c.  */
-#line 106 "parser.h"
+}
+/* Line 1529 of yacc.c.  */
+#line 121 "parser.h"
+	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -110,7 +126,7 @@ typedef union YYSTYPE {
 
 extern YYSTYPE yylval;
 
-#if ! defined (YYLTYPE) && ! defined (YYLTYPE_IS_DECLARED)
+#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
 typedef struct YYLTYPE
 {
   int first_line;
@@ -124,5 +140,3 @@ typedef struct YYLTYPE
 #endif
 
 extern YYLTYPE yylloc;
-
-
